@@ -7,7 +7,7 @@ from sentry_sdk import capture_exception
 
 class NeoNatsClient(NATS):
     def __init__(self):
-        super()
+        super().__init__()
         log_format = "%(asctime)-15s[NSX][%(levelname)s] %(message)s"
 
         logging.basicConfig(format=log_format, level=logging.DEBUG)
